bayespy.inference.vmp.nodes.gamma.GammaMoments
==============================================

.. currentmodule:: bayespy.inference.vmp.nodes.gamma

.. autoclass:: GammaMoments

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~GammaMoments.add_converter
      ~GammaMoments.compute_dims_from_values
      ~GammaMoments.compute_fixed_moments
      ~GammaMoments.get_converter
   
   

   
   
   